@@ -32,7 +32,7 @@ except ImportError, e:
     bz2 = None
 
 # Zope specific
-from ZConfig.components.logger.handlers import HandlerFactory
+from ZConfig.components.logger.handlers import FileHandlerFactory
 
 # Reading and understanding this code requires you understand how
 # zConfig.components.logger works
@@ -163,7 +163,7 @@ def getCompressor(compression):
 ## Handler factory registered by component.xml
 ###
 
-class RotateFileHandlerFactory(HandlerFactory):
+class RotateFileHandlerFactory(FileHandlerFactory):
     """Our factory referenced from the component.xml"""
 
     def create_loghandler(self):
